==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkProjectedTetrahedraMapper.java <==
// java wrapper for vtkProjectedTetrahedraMapper object
//

package vtk;
import vtk.*;

public class vtkProjectedTetrahedraMapper extends vtkUnstructuredGridVolumeMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVisibilitySort_2(vtkVisibilitySort id0);
  public void SetVisibilitySort(vtkVisibilitySort id0)
    { SetVisibilitySort_2(id0); }

  private native long GetVisibilitySort_3();
  public vtkVisibilitySort GetVisibilitySort() {
    long temp = GetVisibilitySort_3();

    if (temp == 0) return null;
    return (vtkVisibilitySort)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void MapScalarsToColors_4(vtkDataArray id0,vtkVolumeProperty id1,vtkDataArray id2);
  public void MapScalarsToColors(vtkDataArray id0,vtkVolumeProperty id1,vtkDataArray id2)
    { MapScalarsToColors_4(id0,id1,id2); }

  private native void TransformPoints_5(vtkPoints id0,double id1[],double id2[],vtkFloatArray id3);
  public void TransformPoints(vtkPoints id0,double id1[],double id2[],vtkFloatArray id3)
    { TransformPoints_5(id0,id1,id2,id3); }

  private native boolean IsSupported_6(vtkRenderWindow id0);
  public boolean IsSupported(vtkRenderWindow id0)
    { return IsSupported_6(id0); }

  public vtkProjectedTetrahedraMapper() { super(); }

  public vtkProjectedTetrahedraMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkProjectedTetrahedraMapper.java <==
// java wrapper for vtkProjectedTetrahedraMapper object
//

package vtk;
import vtk.*;

public class vtkProjectedTetrahedraMapper extends vtkUnstructuredGridVolumeMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVisibilitySort_2(vtkVisibilitySort id0);
  public void SetVisibilitySort(vtkVisibilitySort id0)
    { SetVisibilitySort_2(id0); }

  private native long GetVisibilitySort_3();
  public vtkVisibilitySort GetVisibilitySort() {
    long temp = GetVisibilitySort_3();

    if (temp == 0) return null;
    return (vtkVisibilitySort)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void MapScalarsToColors_4(vtkDataArray id0,vtkVolumeProperty id1,vtkDataArray id2);
  public void MapScalarsToColors(vtkDataArray id0,vtkVolumeProperty id1,vtkDataArray id2)
    { MapScalarsToColors_4(id0,id1,id2); }

  private native void TransformPoints_5(vtkPoints id0,double id1[],double id2[],vtkFloatArray id3);
  public void TransformPoints(vtkPoints id0,double id1[],double id2[],vtkFloatArray id3)
    { TransformPoints_5(id0,id1,id2,id3); }

  private native boolean IsSupported_6(vtkRenderWindow id0);
  public boolean IsSupported(vtkRenderWindow id0)
    { return IsSupported_6(id0); }

  public vtkProjectedTetrahedraMapper() { super(); }

  public vtkProjectedTetrahedraMapper(long id) { super(id); }
  public native long   VTKInit();

}
